==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
            a.item("__isPlainObject", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/WebCancelableBrowserEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let WebCancelableBrowserEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebCancelableBrowserEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebCancelableBrowserEventArgsDetailDescriptionMetadata.a == null) {
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebCancelableBrowserEventArgsDetailDescriptionMetadata.c(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:CancelableBrowserEventArgsDetail");
            a.item("__marshalByValue", "Boolean");
        }
        static d(a) {
            WebCancelableBrowserEventArgsDetailDescriptionMetadata.b(a);
            a.ad("WebCancelableBrowserEventArgsDetail", WebCancelableBrowserEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebCancelableBrowserEventArgsDetailDescriptionMetadata, 'WebCancelableBrowserEventArgsDetailDescriptionMetadata');
    WebCancelableBrowserEventArgsDetailDescriptionMetadata.a = null;
    return WebCancelableBrowserEventArgsDetailDescriptionMetadata;
})();
